@@ -21,7 +21,7 @@ unless (defined $Test::Deep::NoTest::NoTest)
 
 our ($Stack, %Compared, $CompareCache, %WrapCache, $Shallow);
 
-our $VERSION = '0.116';
+our $VERSION = '0.117';
 $VERSION = eval $VERSION;
 
 require Exporter;
@@ -171,7 +171,7 @@ sub import {
     require Test::Deep::String;
   }
 
-  $self->export_to_level(1, @_);
+  $self->export_to_level(1, $self, @_);
 }
 
 # this is ugly, I should never have exported a sub called isa now I
